Accepting request 423942 from Virtualization

1

OBS-URL: https://build.opensuse.org/request/show/423942
OBS-URL: https://build.opensuse.org/package/show/openSUSE:Factory/virtualbox?expand=0&rev=118
This commit is contained in:
Dominique Leuenberger 2016-08-31 12:29:52 +00:00 committed by Git OBS Bridge
commit 4fc1eda9e1
32 changed files with 545 additions and 541 deletions

View File

@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:3d42ff4874bf755bbd24926ecce68ceace8f00f9a098f829ecf2dcb66040354e
size 3492049
oid sha256:abc723f25b8429f5485d07abbfb5ad0c773a2fc85acb388c4b7e9a7c75705819
size 4335525

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:b44ac9e8c701158848ebdfbd1240845f58fa81d31b13fe87e5bf0a671b7453bd
size 76907449

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:76560ad4356f63d1a462392a0af0c2a1ead7d0a27a8a98375584bab4bd058769
size 80040206

View File

@ -1,8 +1,8 @@
<?xml version="1.0"?>
<constraints>
<hardware>
<memory>
<physicalmemory>
<size unit="M">8000</size>
</memory>
</physicalmemory>
</hardware>
</constraints>

View File

@ -1,13 +0,0 @@
Index: VirtualBox-5.0.18/src/VBox/Devices/Storage/DevLsiLogicSCSI.cpp
===================================================================
--- VirtualBox-5.0.18.orig/src/VBox/Devices/Storage/DevLsiLogicSCSI.cpp
+++ VirtualBox-5.0.18/src/VBox/Devices/Storage/DevLsiLogicSCSI.cpp
@@ -3889,7 +3889,7 @@ static DECLCALLBACK(int) lsilogicR3IsaIO
else if (RT_FAILURE(rc))
AssertMsgFailed(("Writing BIOS register failed %Rrc\n", rc));
- return rc;
+ return VINF_SUCCESS;
}
/**

View File

@ -1,78 +0,0 @@
From: Egbert Eich <eich@suse.de>
Date: Mon Apr 25 16:47:41 2016 +0200
Subject: drm/vboxvideo: Add delayed update to support fbdev
Patch-mainline: Not yet
Git-commit: 0671f61d2a240e26c02d5a4d5cb993e1a446e601
References: boo#977200
Due to the virtrual nature of the emulated hardware, the
hardware needs help to know about updates to screen content.
The fb layer provides this with 'deferred IO'.
This patch adds support for this to the vboxvideo DRM driver.
Signed-off-by: Egbert Eich <eich@suse.de>
Signed-off-by: Egbert Eich <eich@suse.com>
---
src/VBox/Additions/linux/drm/vbox_fb.c | 36 ++++++++++++++++++++++++++++++++++
1 file changed, 36 insertions(+)
diff --git a/src/VBox/Additions/linux/drm/vbox_fb.c b/src/VBox/Additions/linux/drm/vbox_fb.c
index 8e0e40d..e8c5a60 100644
--- a/src/VBox/Additions/linux/drm/vbox_fb.c
+++ b/src/VBox/Additions/linux/drm/vbox_fb.c
@@ -68,6 +68,7 @@
#include <drm/drm_crtc_helper.h>
#include "vbox_drv.h"
+#define VBOX_DIRTY_DELAY (HZ / 30)
/**
* Tell the host about dirty rectangles to update.
*/
@@ -162,6 +163,38 @@ static void vbox_dirty_update(struct vbox_fbdev *fbdev,
vbox_bo_unreserve(bo);
}
+static void vbox_deferred_io(struct fb_info *info,
+ struct list_head *pagelist)
+{
+ struct vbox_fbdev *fbdev = info->par;
+ unsigned long start, end, min, max;
+ struct page *page;
+ int y1, y2;
+
+ min = ULONG_MAX;
+ max = 0;
+ list_for_each_entry(page, pagelist, lru) {
+ start = page->index << PAGE_SHIFT;
+ end = start + PAGE_SIZE - 1;
+ min = min(min, start);
+ max = max(max, end);
+ }
+
+ if (min < max) {
+ y1 = min / info->fix.line_length;
+ y2 = (max / info->fix.line_length) + 1;
+ printk(KERN_INFO "%s: Calling dirty update: 0, %d, %d, %d\n",
+ __func__, y1, info->var.xres, y2 - y1 - 1);
+ vbox_dirty_update(fbdev, 0, y1, info->var.xres, y2 - y1 - 1);
+ }
+}
+
+static struct fb_deferred_io vbox_defio =
+{
+ .delay = VBOX_DIRTY_DELAY,
+ .deferred_io = vbox_deferred_io,
+};
+
static void vbox_fillrect(struct fb_info *info,
const struct fb_fillrect *rect)
{
@@ -324,6 +357,9 @@ static int vboxfb_create(struct drm_fb_helper *helper,
info->screen_base = sysram;
info->screen_size = size;
+ info->fbdefio = &vbox_defio;
+ fb_deferred_io_init(info);
+
info->pixmap.flags = FB_PIXMAP_SYSTEM;
DRM_DEBUG_KMS("allocated %dx%d\n",

View File

@ -1,60 +0,0 @@
From: Egbert Eich <eich@suse.de>
Date: Mon Apr 25 09:32:04 2016 +0200
Subject: drm/vboxvideo: Initialize data needed to map fbdev memory
Patch-mainline: Not yet
Git-commit: 4153ec3d267288659638e2397bcae5298e7f5930
References: boo#977200
Due to a missing initialization there was no way to map fbdev memory.
Thus for example using the Xserver with the fbdev driver failed.
This fix adds initialization for fix.smem_start and fix.smem_len
in the fb_info structure, which fixes this problem.
Signed-off-by: Egbert Eich <eich@suse.de>
Signed-off-by: Egbert Eich <eich@suse.com>
---
src/VBox/Additions/linux/drm/vbox_drv.h | 1 +
src/VBox/Additions/linux/drm/vbox_fb.c | 8 ++++++++
src/VBox/Additions/linux/drm/vbox_mode.c | 2 ++
3 files changed, 11 insertions(+)
diff --git a/src/VBox/Additions/linux/drm/vbox_drv.h b/src/VBox/Additions/linux/drm/vbox_drv.h
index fa3eb3c..a9bc156 100644
--- a/src/VBox/Additions/linux/drm/vbox_drv.h
+++ b/src/VBox/Additions/linux/drm/vbox_drv.h
@@ -227,6 +227,7 @@ int vbox_framebuffer_init(struct drm_device *dev,
int vbox_fbdev_init(struct drm_device *dev);
void vbox_fbdev_fini(struct drm_device *dev);
void vbox_fbdev_set_suspend(struct drm_device *dev, int state);
+void vbox_fbdev_set_base(struct vbox_private *vbox, unsigned long gpu_addr);
struct vbox_bo {
struct ttm_buffer_object bo;
diff --git a/src/VBox/Additions/linux/drm/vbox_fb.c b/src/VBox/Additions/linux/drm/vbox_fb.c
index a90f11d..8e0e40d 100644
--- a/src/VBox/Additions/linux/drm/vbox_fb.c
+++ b/src/VBox/Additions/linux/drm/vbox_fb.c
@@ -452,3 +452,11 @@ void vbox_fbdev_set_suspend(struct drm_device *dev, int state)
fb_set_suspend(vbox->fbdev->helper.fbdev, state);
}
+
+void vbox_fbdev_set_base(struct vbox_private *vbox, unsigned long gpu_addr)
+{
+ vbox->fbdev->helper.fbdev->fix.smem_start =
+ vbox->fbdev->helper.fbdev->apertures->ranges[0].base +
+ gpu_addr;
+ vbox->fbdev->helper.fbdev->fix.smem_len = vbox->vram_size - gpu_addr;
+}
diff --git a/src/VBox/Additions/linux/drm/vbox_mode.c b/src/VBox/Additions/linux/drm/vbox_mode.c
index d00ebff..40b6eb0 100644
--- a/src/VBox/Additions/linux/drm/vbox_mode.c
+++ b/src/VBox/Additions/linux/drm/vbox_mode.c
@@ -224,6 +224,8 @@ static int vbox_crtc_do_set_base(struct drm_crtc *crtc,
ret = ttm_bo_kmap(&bo->bo, 0, bo->bo.num_pages, &bo->kmap);
if (ret)
DRM_ERROR("failed to kmap fbcon\n");
+ else
+ vbox_fbdev_set_base(vbox, gpu_addr);
}
vbox_bo_unreserve(bo);

View File

@ -1,7 +1,8 @@
diff -urN VirtualBox-5.0.0.old/Config.kmk VirtualBox-5.0.0/Config.kmk
--- VirtualBox-5.0.0.old/Config.kmk 2015-07-11 13:17:27.273698360 +0200
+++ VirtualBox-5.0.0/Config.kmk 2015-07-11 13:36:31.958812088 +0200
@@ -2344,7 +2344,7 @@
Index: VirtualBox-5.1.2/Config.kmk
===================================================================
--- VirtualBox-5.1.2.orig/Config.kmk
+++ VirtualBox-5.1.2/Config.kmk
@@ -2542,7 +2542,7 @@ else
# The reason for this hack is that the windows kmk_ash cannot deal with $((1+1)).
# Some versions of gcc (e.g. openSUSE11) return only major.minor on `gcc -dumpversion`.
VBOX_GCC_VERSION = $(shell \
@ -10,10 +11,11 @@ diff -urN VirtualBox-5.0.0.old/Config.kmk VirtualBox-5.0.0/Config.kmk
endif
# Find MinGW cross compilers for EFI on non-windows systems. We need to probe
diff -urN VirtualBox-5.0.0.old/configure VirtualBox-5.0.0/configure
--- VirtualBox-5.0.0.old/configure 2015-07-11 13:17:27.273698360 +0200
+++ VirtualBox-5.0.0/configure 2015-07-11 13:37:30.457915488 +0200
@@ -410,8 +410,13 @@
Index: VirtualBox-5.1.2/configure
===================================================================
--- VirtualBox-5.1.2.orig/configure
+++ VirtualBox-5.1.2/configure
@@ -431,8 +431,13 @@ check_gcc()
log_failure "cannot execute '$CXX -dumpversion'"
fail really
fi

View File

@ -0,0 +1,56 @@
Index: VirtualBox-5.1.4/src/VBox/Additions/linux/drm/vbox_ttm.c
===================================================================
--- VirtualBox-5.1.4.orig/src/VBox/Additions/linux/drm/vbox_ttm.c
+++ VirtualBox-5.1.4/src/VBox/Additions/linux/drm/vbox_ttm.c
@@ -221,7 +221,11 @@ static int vbox_bo_move(struct ttm_buffe
struct ttm_mem_reg *new_mem)
{
int r;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 8, 0)
r = ttm_bo_move_memcpy(bo, evict, no_wait_gpu, new_mem);
+#else
+ r = ttm_bo_move_memcpy(bo, evict, interruptible, no_wait_gpu, new_mem);
+#endif
return r;
}
Index: VirtualBox-5.1.4/src/VBox/Additions/linux/drm/vbox_drv.c
===================================================================
--- VirtualBox-5.1.4.orig/src/VBox/Additions/linux/drm/vbox_drv.c
+++ VirtualBox-5.1.4/src/VBox/Additions/linux/drm/vbox_drv.c
@@ -244,9 +244,14 @@ static int vbox_master_set(struct drm_de
return 0;
}
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 8, 0)
static void vbox_master_drop(struct drm_device *dev,
struct drm_file *file_priv,
bool from_release)
+#else
+static void vbox_master_drop(struct drm_device *dev,
+ struct drm_file *file_priv)
+#endif
{
struct vbox_private *vbox = dev->dev_private;
vbox->initial_mode_queried = false;
Index: VirtualBox-5.1.4/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
===================================================================
--- VirtualBox-5.1.4.orig/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
+++ VirtualBox-5.1.4/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
@@ -35,7 +35,7 @@
#include <iprt/assert.h>
#include <iprt/err.h>
#include "r0drv/alloc-r0drv.h"
-
+#include <linux/kmemleak.h>
#if (defined(RT_ARCH_AMD64) || defined(DOXYGEN_RUNNING)) && !defined(RTMEMALLOC_EXEC_HEAP)
# if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23)
@@ -294,6 +294,7 @@ DECLHIDDEN(int) rtR0MemAllocEx(size_t cb
fFlags &= ~RTMEMHDR_FLAG_KMALLOC;
pHdr = vmalloc(cb + sizeof(*pHdr));
}
+ kmemleak_not_leak(pHdr);
}
else
pHdr = vmalloc(cb + sizeof(*pHdr));

View File

@ -1,8 +1,8 @@
Index: VirtualBox-4.3.28/src/VBox/HostDrivers/Support/linux/SUPDrv-linux.c
Index: VirtualBox-5.1.4/src/VBox/HostDrivers/Support/linux/SUPDrv-linux.c
===================================================================
--- VirtualBox-4.3.28.orig/src/VBox/HostDrivers/Support/linux/SUPDrv-linux.c
+++ VirtualBox-4.3.28/src/VBox/HostDrivers/Support/linux/SUPDrv-linux.c
@@ -48,6 +48,12 @@
--- VirtualBox-5.1.4.orig/src/VBox/HostDrivers/Support/linux/SUPDrv-linux.c
+++ VirtualBox-5.1.4/src/VBox/HostDrivers/Support/linux/SUPDrv-linux.c
@@ -50,6 +50,12 @@
# include <iprt/power.h>
# define VBOX_WITH_SUSPEND_NOTIFICATION
#endif
@ -14,4 +14,4 @@ Index: VirtualBox-4.3.28/src/VBox/HostDrivers/Support/linux/SUPDrv-linux.c
+#endif
#include <linux/sched.h>
#ifdef CONFIG_DEVFS_FS
#include <linux/miscdevice.h>

View File

@ -1,76 +0,0 @@
Index: VirtualBox-5.0.18/src/VBox/HostDrivers/VBoxNetAdp/linux/VBoxNetAdp-linux.c
===================================================================
--- VirtualBox-5.0.18.orig/src/VBox/HostDrivers/VBoxNetAdp/linux/VBoxNetAdp-linux.c
+++ VirtualBox-5.0.18/src/VBox/HostDrivers/VBoxNetAdp/linux/VBoxNetAdp-linux.c
@@ -152,7 +152,11 @@ static int vboxNetAdpLinuxXmit(struct sk
pPriv->Stats.tx_packets++;
pPriv->Stats.tx_bytes += pSkb->len;
/* Update transmission time stamp. */
+# if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+ netif_trans_update(pNetDev);
+# else
pNetDev->trans_start = jiffies;
+# endif
/* Nothing else to do, just free the sk_buff. */
dev_kfree_skb(pSkb);
return 0;
Index: VirtualBox-5.0.18/src/VBox/Additions/linux/drm/vbox_drv.h
===================================================================
--- VirtualBox-5.0.18.orig/src/VBox/Additions/linux/drm/vbox_drv.h
+++ VirtualBox-5.0.18/src/VBox/Additions/linux/drm/vbox_drv.h
@@ -285,7 +285,11 @@ static inline int vbox_bo_reserve(struct
{
int ret;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+ ret = ttm_bo_reserve(&bo->bo, true, no_wait, NULL);
+#else
ret = ttm_bo_reserve(&bo->bo, true, no_wait, false, 0);
+#endif
if (ret)
{
if (ret != -ERESTARTSYS && ret != -EBUSY)
Index: VirtualBox-5.0.18/src/VBox/Additions/linux/drm/vbox_main.c
===================================================================
--- VirtualBox-5.0.18.orig/src/VBox/Additions/linux/drm/vbox_main.c
+++ VirtualBox-5.0.18/src/VBox/Additions/linux/drm/vbox_main.c
@@ -203,7 +203,11 @@ vbox_user_framebuffer_create(struct drm_
int ret;
LogFunc(("vboxvideo: %d\n", __LINE__));
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+ obj = drm_gem_object_lookup(filp, mode_cmd->handles[0]);
+#else
obj = drm_gem_object_lookup(dev, filp, mode_cmd->handles[0]);
+#endif
if (obj == NULL)
return ERR_PTR(-ENOENT);
@@ -546,7 +550,11 @@ vbox_dumb_mmap_offset(struct drm_file *f
LogFunc(("vboxvideo: %d: dev=%p, handle=%u\n", __LINE__,
dev, (unsigned)handle));
mutex_lock(&dev->struct_mutex);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+ obj = drm_gem_object_lookup(file, handle);
+#else
obj = drm_gem_object_lookup(dev, file, handle);
+#endif
if (obj == NULL) {
ret = -ENOENT;
goto out_unlock;
Index: VirtualBox-5.0.18/src/VBox/Additions/linux/drm/vbox_mode.c
===================================================================
--- VirtualBox-5.0.18.orig/src/VBox/Additions/linux/drm/vbox_mode.c
+++ VirtualBox-5.0.18/src/VBox/Additions/linux/drm/vbox_mode.c
@@ -714,7 +714,11 @@ static int vbox_cursor_set2(struct drm_c
|| !(caps & VMMDEV_MOUSE_HOST_WANTS_ABSOLUTE))
return -EINVAL;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+ obj = drm_gem_object_lookup(file_priv, handle);
+#else
obj = drm_gem_object_lookup(crtc->dev, file_priv, handle);
+#endif
if (obj)
{
bo = gem_to_vbox_bo(obj);

View File

@ -1,8 +1,10 @@
--- a/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp 2014-02-25 18:08:58.000000000 +0100
+++ b/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp 2014-03-03 15:18:07.298245235 +0100
@@ -203,15 +203,15 @@
diff -Pdpru VirtualBox-4.3.18.orig/src/VBox/Main/webservice/Makefile.kmk VirtualBox-4.3.18/src/VBox/Main/webservice/Makefile.kmk
--- VirtualBox-4.3.18.orig/src/VBox/Main/webservice/Makefile.kmk 2014-10-11 14:07:33.000000000 +0200
+++ VirtualBox-4.3.18/src/VBox/Main/webservice/Makefile.kmk 2014-10-13 17:10:53.689539003 +0200
@@ -683,7 +683,7 @@ $(VBOXWEB_OUT_DIR)/gsoap_generate_all_ts
: $(VBOXWEB_GSOAPH_FROM_GSOAP) $(VBOXWEB_GSOAPH_FROM_XSLT) $(VBOX_NSMAP) $(RECOMPILE_ON_MAKEFILE_CURRENT) | $$(dir $$@)
Index: VirtualBox-5.1.4/src/VBox/Main/webservice/Makefile.kmk
===================================================================
--- VirtualBox-5.1.4.orig/src/VBox/Main/webservice/Makefile.kmk
+++ VirtualBox-5.1.4/src/VBox/Main/webservice/Makefile.kmk
@@ -724,7 +724,7 @@ $(VBOXWEB_OUT_DIR)/gsoap_generate_all_ts
$(RECOMPILE_ON_MAKEFILE_CURRENT) | $$(dir $$@)
$(call MSG_GENERATE,,lots of files,$(GSOAPH_RELEVANT))
$(RM) -f $@
- $(REDIRECT) -C $(VBOXWEB_OUT_DIR) -- $(VBOX_SOAPCPP2) $(VBOXWEB_SOAPCPP2_SKIP_FILES) -L -2 -w -I$(VBOX_PATH_GSOAP_IMPORT) $(GSOAPH_RELEVANT)
+ $(REDIRECT) -C $(VBOXWEB_OUT_DIR) -- $(VBOX_SOAPCPP2) $(VBOXWEB_SOAPCPP2_SKIP_FILES) -z1 -L -2 -w -I$(VBOX_PATH_GSOAP_IMPORT) $(GSOAPH_RELEVANT)
$(APPEND) $@ done
# Copy the generated headers and stuff. This was split into a separate rule
ifeq ($(KBUILD_TARGET),win) # MSC -Wall workaround.
$(CP) -f "$(VBOXWEB_SOAP_CLIENT_H)" "$(VBOXWEB_SOAP_CLIENT_H).tmp"
$(SED) -f $(VBOX_PATH_WEBSERVICE)/stdsoap2.sed --output "$(VBOXWEB_SOAP_CLIENT_H)" "$(VBOXWEB_SOAP_CLIENT_H).tmp"

View File

@ -1,7 +1,8 @@
diff -urN VirtualBox-5.0.0.old/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp VirtualBox-5.0.0/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
--- VirtualBox-5.0.0.old/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp 2015-07-11 13:17:27.885699492 +0200
+++ VirtualBox-5.0.0/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp 2015-07-11 13:21:56.912197474 +0200
@@ -68,7 +68,7 @@
Index: VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
+++ VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
@@ -68,7 +68,7 @@ void UIGlobalSettingsUpdate::loadToCache
void UIGlobalSettingsUpdate::getFromCache()
{
/* Apply internal variables data to QWidget(s): */
@ -10,10 +11,11 @@ diff -urN VirtualBox-5.0.0.old/src/VBox/Frontends/VirtualBox/src/settings/global
if (m_pCheckBoxUpdate->isChecked())
{
m_pComboBoxUpdatePeriod->setCurrentIndex(m_cache.m_periodIndex);
diff -urN VirtualBox-5.0.0.old/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp VirtualBox-5.0.0/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
--- VirtualBox-5.0.0.old/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp 2015-07-11 13:17:27.885699492 +0200
+++ VirtualBox-5.0.0/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp 2015-07-11 13:23:13.230338850 +0200
@@ -106,16 +106,6 @@
Index: VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
+++ VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
@@ -104,16 +104,6 @@ UISettingsDialogGlobal::UISettingsDialog
iPageIndex, "#input", pSettingsPage);
break;
}
@ -30,7 +32,7 @@ diff -urN VirtualBox-5.0.0.old/src/VBox/Frontends/VirtualBox/src/settings/UISett
/* Language page: */
case GlobalSettingsPageType_Language:
{
@@ -254,8 +244,6 @@
@@ -252,8 +242,6 @@ void UISettingsDialogGlobal::retranslate
m_pSelector->setItemText(GlobalSettingsPageType_Input, tr("Input"));
#ifdef VBOX_GUI_WITH_NETWORK_MANAGER

View File

@ -1,8 +1,8 @@
Index: VirtualBox-4.3.14/Config.kmk
Index: VirtualBox-5.1.4/Config.kmk
===================================================================
--- VirtualBox-4.3.14.orig/Config.kmk
+++ VirtualBox-4.3.14/Config.kmk
@@ -3963,6 +3963,9 @@ TEMPLATE_VBOXR3HARDENEDEXE_LDFLAGS.darwi
--- VirtualBox-5.1.4.orig/Config.kmk
+++ VirtualBox-5.1.4/Config.kmk
@@ -4852,6 +4852,9 @@ TEMPLATE_VBOXR3HARDENEDEXE_LDFLAGS.darwi
ifeq ($(KBUILD_TARGET),linux)
# not necessary except USE_LIB_PCAP is defined in SUPR3HardenedMain.cpp
# TEMPLATE_VBOXR3HARDENEDEXE_LIBS += cap
@ -12,10 +12,10 @@ Index: VirtualBox-4.3.14/Config.kmk
endif
ifeq ($(KBUILD_TARGET),win) # No CRT!
TEMPLATE_VBOXR3HARDENEDEXE_SDKS = VBOX_NTDLL $(TEMPLATE_VBOXR3EXE_SDKS)
@@ -3981,8 +3984,8 @@ ifeq ($(KBUILD_TARGET),win) # No CRT!
TEMPLATE_VBOXR3HARDENEDEXE_LIBS.x86 = $(NOT_SUCH_VARIABLE)
@@ -4871,8 +4874,8 @@ ifeq ($(KBUILD_TARGET),win) # No CRT!
TEMPLATE_VBOXR3HARDENEDEXE_LIBS.amd64 = $(NOT_SUCH_VARIABLE)
else ifn1of ($(KBUILD_TARGET), os2)
else ifn1of ($(KBUILD_TARGET), os2 solaris)
# We want to keep the RPATH on Solaris to be able to find libgcc_1/libstdc++ within $(VBOX_WITH_RUNPATH)
- TEMPLATE_VBOXR3HARDENEDEXE_LDFLAGS = $(filter-out '$(VBOX_GCC_RPATH_OPT)%,$(TEMPLATE_VBOXR3EXE_LDFLAGS))
- TEMPLATE_VBOXR3HARDENEDEXE_LDFLAGS.linux = $(filter-out $(VBOX_GCC_ORIGIN_OPT),$(TEMPLATE_VBOXR3EXE_LDFLAGS.linux))
+ TEMPLATE_VBOXR3HARDENEDEXE_LDFLAGS = $(filter-out '$(VBOX_GCC_RPATH_OPT)%,$(TEMPLATE_VBOXR3EXE_LDFLAGS)) -pie

View File

@ -1,7 +1,7 @@
Index: VirtualBox-4.3.6/src/VBox/Main/webservice/Makefile.kmk
Index: VirtualBox-5.1.2/src/VBox/Main/webservice/Makefile.kmk
===================================================================
--- VirtualBox-4.3.6.orig/src/VBox/Main/webservice/Makefile.kmk
+++ VirtualBox-4.3.6/src/VBox/Main/webservice/Makefile.kmk
--- VirtualBox-5.1.2.orig/src/VBox/Main/webservice/Makefile.kmk
+++ VirtualBox-5.1.2/src/VBox/Main/webservice/Makefile.kmk
@@ -303,6 +303,7 @@ endif
vboxwebsrv_LIBS += \
$(PATH_STAGE_LIB)/vboxsoap$(VBOX_SUFF_LIB) \
@ -10,7 +10,7 @@ Index: VirtualBox-4.3.6/src/VBox/Main/webservice/Makefile.kmk
$(LIB_RUNTIME)
vboxwebsrv_LIBS.solaris += socket nsl
ifdef VBOX_WITH_WEBSERVICES_SSL
@@ -480,6 +481,7 @@ $$(VBOX_JWSSRC_JAR): $$(VBOX_JWS_JAR) |
@@ -483,6 +484,7 @@ $$(VBOX_JWSSRC_JAR): $$(VBOX_JWS_JAR) |
webtest_LIBS += \
$(PATH_STAGE_LIB)/vboxsoap$(VBOX_SUFF_LIB) \
$(VBOX_GSOAP_CXX_LIBS) \

View File

@ -155,7 +155,7 @@ Index: src/VBox/Main/glue/com.cpp
===================================================================
--- src/VBox/Main/glue/com.cpp.orig
+++ src/VBox/Main/glue/com.cpp
@@ -292,7 +292,7 @@ static DECLCALLBACK(void) vboxHeaderFoot
@@ -283,7 +283,7 @@ static DECLCALLBACK(void) vboxHeaderFoot
#endif
"Log opened %s\n",
g_pszLogEntity, VBOX_VERSION_STRING, RTBldCfgRevision(),
@ -168,7 +168,7 @@ Index: src/VBox/Additions/common/VBoxService/VBoxService.cpp
===================================================================
--- src/VBox/Additions/common/VBoxService/VBoxService.cpp.orig
+++ src/VBox/Additions/common/VBoxService/VBoxService.cpp
@@ -238,7 +238,7 @@ static DECLCALLBACK(void) vgsvcLogHeader
@@ -241,7 +241,7 @@ static DECLCALLBACK(void) vgsvcLogHeader
"VBoxService %s r%s (verbosity: %u) %s (%s %s) release log\n"
"Log opened %s\n",
RTBldCfgVersion(), RTBldCfgRevisionStr(), g_cVerbosity, VBOX_BUILD_TARGET,

View File

@ -14,7 +14,7 @@ Index: VirtualBox-4.3.6/src/apps/VBoxPermissionMessage/Makefile.kmk
===================================================================
--- /dev/null
+++ VirtualBox-4.3.6/src/apps/VBoxPermissionMessage/Makefile.kmk
@@ -0,0 +1,31 @@
@@ -0,0 +1,35 @@
+# $Id: Makefile.kmk 28800 2010-04-27 08:22:32Z vboxsync $
+## @file
+#
@ -38,9 +38,13 @@ Index: VirtualBox-4.3.6/src/apps/VBoxPermissionMessage/Makefile.kmk
+
+PROGRAMS += VBoxPermissionMessage
+
+VBoxPermissionMessage_TEMPLATE = VBOXQT4GUIEXE
+VBoxPermissionMessage_TEMPLATE = VBOXQTGUIEXE
+VBoxPermissionMessage_SOURCES = VBoxPermissionMessage.cpp
+VBoxPermissionMessage_QT_MODULES = Core Gui
+ifdef VBOX_WITH_QTGUI_V5
+ # Qt5 requires additional modules:
+ VBoxPermissionMessage_QT_MODULES += Widgets
+endif # VBOX_WITH_QTGUI_V5
+
+#INSTALLS += VBoxPermissionMessage
+
@ -51,8 +55,8 @@ Index: VirtualBox-4.3.6/src/apps/VBoxPermissionMessage/VBoxPermissionMessage.cpp
--- /dev/null
+++ VirtualBox-4.3.6/src/apps/VBoxPermissionMessage/VBoxPermissionMessage.cpp
@@ -0,0 +1,12 @@
+#include <QtGui/QApplication>
+#include <QtGui/QMessageBox>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QMessageBox>
+int main(int argc, char *argv[])
+{
+ QApplication app(argc, argv);

View File

@ -1,8 +1,8 @@
Index: VirtualBox-4.3.6/src/libs/xpcom18a4/python/gen_python_deps.py
Index: VirtualBox-5.1.2/src/libs/xpcom18a4/python/gen_python_deps.py
===================================================================
--- VirtualBox-4.3.6.orig/src/libs/xpcom18a4/python/gen_python_deps.py
+++ VirtualBox-4.3.6/src/libs/xpcom18a4/python/gen_python_deps.py
@@ -71,7 +71,7 @@ def main(argv):
--- VirtualBox-5.1.2.orig/src/libs/xpcom18a4/python/gen_python_deps.py
+++ VirtualBox-5.1.2/src/libs/xpcom18a4/python/gen_python_deps.py
@@ -75,7 +75,7 @@ def main(argv):
else:
multi = 1
@ -11,15 +11,15 @@ Index: VirtualBox-4.3.6/src/libs/xpcom18a4/python/gen_python_deps.py
prefixes = ["/usr"]
versions = [str(sys.version_info[0])+'.'+str(sys.version_info[1])]
@@ -92,22 +92,23 @@ def main(argv):
for v in versions:
@@ -98,22 +98,23 @@ def main(argv):
continue
for p in prefixes:
c = checkPair(p, v, dllpre, dllsuff, bitness_magic)
- if c is not None:
+ if c:
known[v] = c
break
- keys = known.keys()
- keys = list(known.keys())
- # we want default to be the lowest versioned Python
- keys.sort()
- d = None

View File

@ -1,8 +1,8 @@
Index: VirtualBox-4.3.6/src/VBox/Devices/PC/vbox.dsl
Index: VirtualBox-5.1.2/src/VBox/Devices/PC/vbox.dsl
===================================================================
--- VirtualBox-4.3.6.orig/src/VBox/Devices/PC/vbox.dsl
+++ VirtualBox-4.3.6/src/VBox/Devices/PC/vbox.dsl
@@ -848,7 +848,7 @@ DefinitionBlock ("DSDT.aml", "DSDT", 1,
--- VirtualBox-5.1.2.orig/src/VBox/Devices/PC/vbox.dsl
+++ VirtualBox-5.1.2/src/VBox/Devices/PC/vbox.dsl
@@ -1179,7 +1179,7 @@ DefinitionBlock ("DSDT.aml", "DSDT", 1,
Device (SMC)
{
Name (_HID, EisaId ("APP0001"))

View File

@ -16,7 +16,7 @@ Index: a/src/apps/VBoxUSB_DevRules/Makefile.kmk
===================================================================
--- a/src/apps/VBoxUSB_DevRules/Makefile.kmk (revision 0)
+++ b/src/apps/VBoxUSB_DevRules/Makefile.kmk (working copy)
@@ -0,0 +1,29 @@
@@ -0,0 +1,33 @@
+# $Id: Makefile.kmk 28800 2010-04-27 08:22:32Z vboxsync $
+## @file
+#
@ -37,9 +37,13 @@ Index: a/src/apps/VBoxUSB_DevRules/Makefile.kmk
+
+PROGRAMS += VBoxUSB_DevRules
+
+VBoxUSB_DevRules_TEMPLATE = VBOXQT4GUIEXE
+VBoxUSB_DevRules_TEMPLATE = VBOXQTGUIEXE
+VBoxUSB_DevRules_SOURCES = VBoxUSB_DevRules.cpp
+VBoxUSB_DevRules_QT_MODULES = Core Gui
+ifdef VBOX_WITH_QTGUI_V5
+ # Qt5 requires additional modules:
+ VBoxUSB_DevRules_QT_MODULES += Widgets
+endif # VBOX_WITH_QTGUI_V5
+
+#INSTALLS += VBoxUSB_DevRules
+
@ -51,8 +55,8 @@ Index: a/src/apps/VBoxUSB_DevRules/VBoxUSB_DevRules.cpp
--- a/src/apps/VBoxUSB_DevRules/VBoxUSB_DevRules.cpp (revision 0)
+++ b/src/apps/VBoxUSB_DevRules/VBoxUSB_DevRules.cpp (working copy)
@@ -0,0 +1,13 @@
+#include <QtGui/QApplication>
+#include <QtGui/QMessageBox>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QMessageBox>
+int main(int argc, char *argv[])
+{
+ QApplication app(argc, argv);

View File

@ -1,7 +1,7 @@
Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
Index: VirtualBox-5.1.4/src/VBox/Additions/linux/installer/vboxadd.sh
===================================================================
--- VirtualBox-5.0.18.orig/src/VBox/Additions/linux/installer/vboxadd.sh
+++ VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
--- VirtualBox-5.1.4.orig/src/VBox/Additions/linux/installer/vboxadd.sh
+++ VirtualBox-5.1.4/src/VBox/Additions/linux/installer/vboxadd.sh
@@ -23,9 +23,12 @@
# Provides: vboxadd
# Required-Start:
@ -15,8 +15,8 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
+# Short-Description: VirtualBox Linux Additions kernel modules
### END INIT INFO
PATH=$PATH:/bin:/sbin:/usr/sbin
@@ -148,7 +151,6 @@ fail()
## @todo This file duplicates a lot of script with vboxdrv.sh. When making
@@ -94,7 +97,6 @@ fail()
dev=/dev/vboxguest
userdev=/dev/vboxuser
@ -24,7 +24,7 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
owner=vboxadd
group=1
@@ -226,12 +228,6 @@ do_vboxguest_non_udev()
@@ -140,12 +142,6 @@ do_vboxguest_non_udev()
fail "Cannot create device $dev with major $maj and minor $min"
}
fi
@ -37,7 +37,7 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
if [ ! -c $userdev ]; then
maj=10
@@ -242,12 +238,6 @@ do_vboxguest_non_udev()
@@ -156,12 +152,6 @@ do_vboxguest_non_udev()
rmmod vboxguest 2>/dev/null
fail "Cannot create device $userdev with major $maj and minor $min"
}
@ -50,10 +50,10 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
fi
fi
}
@@ -255,13 +245,6 @@ do_vboxguest_non_udev()
start()
{
begin "Starting the VirtualBox Guest Additions ";
@@ -171,13 +161,6 @@ start()
begin "Starting the VirtualBox Guest Additions" console;
# If we got this far assume that the slow set-up has been done.
QUICKSETUP=yes
- if test -r $config; then
- . $config
- else
@ -64,28 +64,38 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
uname -r | grep -q -E '^2\.6|^3|^4' 2>/dev/null &&
ps -A -o comm | grep -q '/*udevd$' 2>/dev/null ||
no_udev=1
@@ -300,7 +283,7 @@ start()
$MODPROBE vboxvideo > /dev/null 2>&1
@@ -193,7 +176,7 @@ start()
$MODPROBE vboxguest >/dev/null 2>&1 || {
setup
$MODPROBE vboxguest >/dev/null 2>&1 || {
- /sbin/rcvboxadd-x11 cleanup
+ #/sbin/rcvboxadd-x11 cleanup
fail "modprobe vboxguest failed"
}
}
@@ -217,7 +200,7 @@ start()
}
# Put the X.Org driver in place. This is harmless if it is not needed.
- /sbin/rcvboxadd-x11 setup
+# /sbin/rcvboxadd-x11 setup
+ #/sbin/rcvboxadd-x11 setup
# Install the guest OpenGL drivers. For now we don't support
# multi-architecture installations
rm -rf /etc/ld.so.conf.d/00vboxvideo.conf
@@ -475,7 +458,7 @@ extra_setup()
rm -f /etc/ld.so.conf.d/00vboxvideo.conf
@@ -378,7 +361,7 @@ extra_setup()
ln -sf "$lib_path/$PACKAGE/mount.vboxsf" /sbin
# And an rc file to re-build the kernel modules and re-set-up the X server.
ln -sf "$lib_path/$PACKAGE/vboxadd" /sbin/rcvboxadd
- ln -sf "$lib_path/$PACKAGE/vboxadd-x11" /sbin/rcvboxadd-x11
+# ln -sf "$lib_path/$PACKAGE/vboxadd-x11" /sbin/rcvboxadd-x11
# At least Fedora 11 and Fedora 12 require the correct security context when
# executing this command from service scripts. Shouldn't hurt for other
# distributions.
@@ -497,49 +480,13 @@ extra_setup()
+ #ln -sf "$lib_path/$PACKAGE/vboxadd-x11" /sbin/rcvboxadd-x11
# And a post-installation script for rebuilding modules when a new kernel
# is installed.
mkdir -p /etc/kernel/postinst.d /etc/kernel/prerm.d
@@ -411,49 +394,13 @@ EOF
# setup_script
setup()
{
- begin "Building Guest Additions kernel modules" console
- if test -r $config; then
- . $config
- else
@ -99,20 +109,22 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
- rm -f $LOG
- MODULE_SRC="$INSTALL_DIR/src/vboxguest-$INSTALL_VER"
- BUILDINTMP="$MODULE_SRC/build_in_tmp"
- DODKMS="$MODULE_SRC/do_dkms"
- chcon -t bin_t "$BUILDINTMP" > /dev/null 2>&1
- chcon -t bin_t "$DODKMS" > /dev/null 2>&1
-
- setup_modules
- mod_succ="$?"
- if setup_modules; then
- mod_succ=0
- else
- mod_succ=1
- show_error "Please check that you have gcc, make, the header files for your Linux kernel and possibly perl installed."
- fi
- test -n "${QUICKSETUP}" && return "${mod_succ}"
- extra_setup
- if [ "$mod_succ" -eq "0" ]; then
- if running_vboxguest || running_vboxadd; then
- printf "You should restart your guest to make sure the new modules are actually used\n\n"
- else
- start
- begin "You should restart your guest to make sure the new modules are actually used" console
- fi
- fi
- return "${mod_succ}"
+ begin "Recompiling VirtualBox kernel module, NOT. It has been packaged."
+ succ_msg
}
@ -124,9 +136,6 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
- . $config
- test -n "$INSTALL_DIR" -a -n "$INSTALL_VER" ||
- fail "Configuration file $config not complete"
- DODKMS="$INSTALL_DIR/src/vboxguest-$INSTALL_VER/do_dkms"
- elif test -x ./do_dkms; then # Executing as part of the installer...
- DODKMS=./do_dkms
- else
- fail "Configuration file $config not found"
- fi
@ -134,18 +143,18 @@ Index: VirtualBox-5.0.18/src/VBox/Additions/linux/installer/vboxadd.sh
# Delete old versions of VBox modules.
cleanup_modules
depmod
@@ -550,12 +497,12 @@ cleanup()
@@ -464,12 +411,12 @@ cleanup()
done
# Clean-up X11-related bits
- /sbin/rcvboxadd-x11 cleanup
+# /sbin/rcvboxadd-x11 cleanup
+ #/sbin/rcvboxadd-x11 cleanup
# Remove other files
rm /sbin/mount.vboxsf 2>/dev/null
rm /sbin/rcvboxadd 2>/dev/null
- rm /sbin/rcvboxadd-x11 2>/dev/null
+# rm /sbin/rcvboxadd-x11 2>/dev/null
+ #rm /sbin/rcvboxadd-x11 2>/dev/null
rm -f /etc/kernel/postinst.d/vboxadd /etc/kernel/prerm.d/vboxadd
rmdir -p /etc/kernel/postinst.d /etc/kernel/prerm.d 2>/dev/null
rm /etc/udev/rules.d/60-vboxadd.rules 2>/dev/null
}

View File

@ -1,7 +1,7 @@
Index: src/VBox/Installer/linux/vboxdrv.sh.in
Index: VirtualBox-5.1.4/src/VBox/Installer/linux/vboxdrv.sh
===================================================================
--- src/VBox/Installer/linux/vboxdrv.sh.in.orig
+++ src/VBox/Installer/linux/vboxdrv.sh.in
--- VirtualBox-5.1.4.orig/src/VBox/Installer/linux/vboxdrv.sh
+++ VirtualBox-5.1.4/src/VBox/Installer/linux/vboxdrv.sh
@@ -19,11 +19,12 @@
#
### BEGIN INIT INFO
@ -18,65 +18,32 @@ Index: src/VBox/Installer/linux/vboxdrv.sh.in
+# Description: VirtualBox Linux kernel module
### END INIT INFO
PATH=/sbin:/bin:/usr/sbin:/usr/bin:$PATH
@@ -191,13 +192,6 @@ start()
## @todo This file duplicates a lot of script with vboxadd.sh. When making
@@ -258,13 +259,6 @@ start()
fi
fi
# ensure permissions
- if ! chown :%GROUP% $DEVICE 2>/dev/null; then
- if ! chown :"${GROUP}" $DEVICE 2>/dev/null; then
- rmmod vboxpci 2>/dev/null
- rmmod vboxnetadp 2>/dev/null
- rmmod vboxnetflt 2>/dev/null
- rmmod vboxdrv 2>/dev/null
- failure "Cannot change group %GROUP% for device $DEVICE"
- failure "Cannot change group ${GROUP} for device $DEVICE"
- fi
if ! $MODPROBE vboxnetflt > /dev/null 2>&1; then
failure "modprobe vboxnetflt failed. Please use 'dmesg' to find out why"
fi
@@ -295,70 +289,8 @@ stop_vms()
@@ -395,36 +389,8 @@ cleanup()
# setup_script
setup()
{
- stop
- DKMS=`which dkms 2>/dev/null`
- if [ -n "$DKMS" ]; then
- begin_msg "Uninstalling old VirtualBox DKMS kernel modules"
- $DODKMS uninstall vboxhost vboxdrv vboxnetflt vboxnetadp > $LOG
- succ_msg
- fi
- if find /lib/modules/`uname -r` -name "vboxpci\.*" 2>/dev/null|grep -q vboxpci; then
- begin_msg "Removing old VirtualBox pci kernel module"
- find /lib/modules/`uname -r` -name "vboxpci\.*" 2>/dev/null|xargs rm -f 2>/dev/null
- succ_msg
- fi
- if find /lib/modules/`uname -r` -name "vboxnetadp\.*" 2>/dev/null|grep -q vboxnetadp; then
- begin_msg "Removing old VirtualBox netadp kernel module"
- find /lib/modules/`uname -r` -name "vboxnetadp\.*" 2>/dev/null|xargs rm -f 2>/dev/null
- succ_msg
- fi
- if find /lib/modules/`uname -r` -name "vboxnetflt\.*" 2>/dev/null|grep -q vboxnetflt; then
- begin_msg "Removing old VirtualBox netflt kernel module"
- find /lib/modules/`uname -r` -name "vboxnetflt\.*" 2>/dev/null|xargs rm -f 2>/dev/null
- succ_msg
- fi
- if find /lib/modules/`uname -r` -name "vboxdrv\.*" 2>/dev/null|grep -q vboxdrv; then
- begin_msg "Removing old VirtualBox kernel module"
- find /lib/modules/`uname -r` -name "vboxdrv\.*" 2>/dev/null|xargs rm -f 2>/dev/null
- succ_msg
- fi
- if [ -n "$DKMS" ]; then
- begin_msg "Trying to register the VirtualBox kernel modules using DKMS"
- if ! $DODKMS install vboxhost $VERSION >> $LOG; then
- fail_msg "Failed, trying without DKMS"
- DKMS=""
- fi
- fi
- if [ -z "$DKMS" ]; then
- begin_msg "Recompiling VirtualBox kernel modules"
- begin_msg "Building VirtualBox kernel modules" console
- cleanup
- if ! $BUILDINTMP \
- --save-module-symvers /tmp/vboxdrv-Module.symvers \
- --module-source "$MODULE_SRC/vboxdrv" \
- --no-print-directory install >> $LOG 2>&1; then
- "${INSTALL_DIR}/check_module_dependencies.sh"
- failure "Look at $LOG to find out what went wrong"
- fi
- if ! $BUILDINTMP \
@ -97,11 +64,11 @@ Index: src/VBox/Installer/linux/vboxdrv.sh.in
- --no-print-directory install >> $LOG 2>&1; then
- failure "Look at $LOG to find out what went wrong"
- fi
- fi
- rm -f /etc/vbox/module_not_compiled
- depmod -a
- succ_msg "VirtualBox kernel modules built"
+ begin_msg "Recompiling VirtualBox kernel module, NOT. It has been packaged."
succ_msg
- start
+ succ_msg ""
}
dmnstatus()

View File

@ -1,7 +1,7 @@
Index: VirtualBox-4.1.8_OSE/src/VBox/Installer/linux/vboxweb-service.sh
Index: VirtualBox-5.1.2/src/VBox/Installer/linux/vboxweb-service.sh
===================================================================
--- VirtualBox-4.1.8_OSE.orig/src/VBox/Installer/linux/vboxweb-service.sh
+++ VirtualBox-4.1.8_OSE/src/VBox/Installer/linux/vboxweb-service.sh
--- VirtualBox-5.1.2.orig/src/VBox/Installer/linux/vboxweb-service.sh
+++ VirtualBox-5.1.2/src/VBox/Installer/linux/vboxweb-service.sh
@@ -20,7 +20,7 @@
# Provides: vboxweb-service
# Required-Start: vboxdrv
@ -11,12 +11,3 @@ Index: VirtualBox-4.1.8_OSE/src/VBox/Installer/linux/vboxweb-service.sh
# Default-Stop: 0 1 6
# Description: VirtualBox web service API
### END INIT INFO
@@ -50,7 +50,7 @@ if [ -f /etc/redhat-release ]; then
PIDFILE="/var/lock/subsys/vboxweb-service"
elif [ -f /etc/SuSE-release ]; then
system=suse
- PIDFILE="/var/lock/subsys/vboxweb-service"
+ PIDFILE="/var/run/vboxweb-service"
elif [ -f /etc/debian_version ]; then
system=debian
PIDFILE="/var/run/vboxweb-service"

View File

@ -1,8 +1,8 @@
Index: VirtualBox-5.0.17/src/VBox/Additions/common/crOpenGL/Makefile.kmk
Index: VirtualBox-5.1.2/src/VBox/Additions/common/crOpenGL/Makefile.kmk
===================================================================
--- VirtualBox-5.0.17.orig/src/VBox/Additions/common/crOpenGL/Makefile.kmk
+++ VirtualBox-5.0.17/src/VBox/Additions/common/crOpenGL/Makefile.kmk
@@ -227,7 +227,7 @@ if1of ($(KBUILD_TARGET), linux solaris f
--- VirtualBox-5.1.2.orig/src/VBox/Additions/common/crOpenGL/Makefile.kmk
+++ VirtualBox-5.1.2/src/VBox/Additions/common/crOpenGL/Makefile.kmk
@@ -221,7 +221,7 @@ if1of ($(KBUILD_TARGET), linux solaris f
dl
endif
else

View File

@ -1,8 +0,0 @@
KERNEL=="vboxdrv", NAME="vboxdrv", OWNER="root", GROUP="vboxusers", MODE="0660"
#
#these lines below give access permission to vboxusers to properly work with usb nodes, but enabling them could be security risk (bnc#664520) !!
#if you can live with this security problem put these lines below in to the new file /etc/udev/rules.d/60-vboxdrv.rules so they will stay enabled also after package update
#SUBSYSTEM=="usb_device", ACTION=="add", RUN+="/usr/lib/udev/VBoxCreateUSBNode.sh $major $minor $attr{bDeviceClass} vboxusers"
#SUBSYSTEM=="usb", ACTION=="add", ENV{DEVTYPE}=="usb_device", RUN+="/usr/lib/udev/VBoxCreateUSBNode.sh $major $minor $attr{bDeviceClass} vboxusers"
#SUBSYSTEM=="usb_device", ACTION=="remove", RUN+="/usr/lib/udev/VBoxCreateUSBNode.sh --remove $major $minor"
#SUBSYSTEM=="usb", ACTION=="remove", ENV{DEVTYPE}=="usb_device", RUN+="/usr/lib/udev/VBoxCreateUSBNode.sh --remove $major $minor"

View File

@ -14,3 +14,13 @@
#
#SHUTDOWN_USERS="foo bar"
#SHUTDOWN="savestate"
# -------------------------------------------------------------------------------------------------
# By default, vboxdrv creates a file /etc/udev/rules.d/60-vboxdrv.rules every time, it is started,
# that allows full control of this hosts usb devices in virtual machines (given, you allow accessing
# them with the GUI).
# In order to control this ability yourself, copy the generated /etc/udev/rules.d/60-vboxdrv.rules
# file to another name and modify to your needs, e.g. comment out all lines beginning with SUBSYSTEM,
# which will make this hosts usb devices inaccessible AND enable the next line.
#INSTALL_NO_UDEV=1

View File

@ -1,7 +1,8 @@
diff -urN VirtualBox-5.0.0.old/src/VBox/Main/Makefile.kmk VirtualBox-5.0.0/src/VBox/Main/Makefile.kmk
--- VirtualBox-5.0.0.old/src/VBox/Main/Makefile.kmk 2015-07-11 13:17:27.573698915 +0200
+++ VirtualBox-5.0.0/src/VBox/Main/Makefile.kmk 2015-07-11 14:34:21.357349819 +0200
@@ -1199,7 +1199,7 @@
Index: VirtualBox-5.1.2/src/VBox/Main/Makefile.kmk
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Main/Makefile.kmk
+++ VirtualBox-5.1.2/src/VBox/Main/Makefile.kmk
@@ -1331,7 +1331,7 @@ $(VBoxAPIWrap_0_OUTDIR)/VBoxAPI.d.ts \
$(QUIET)$(VBOX_XSLTPROC) --stringparam KBUILD_HOST $(KBUILD_HOST) \
--stringparam generating "dtrace-probes" \
-o "$@" $(VBoxAPIWrap_VBOX_XSLT) $<
@ -10,3 +11,17 @@ diff -urN VirtualBox-5.0.0.old/src/VBox/Main/Makefile.kmk VirtualBox-5.0.0/src/V
"$(VBOX_PATH_MAIN_SRC)/src-all/VBoxAPI-start.d" \
"$@" \
"$(VBOX_PATH_MAIN_SRC)/src-all/VBoxAPI-end.d"
Index: VirtualBox-5.0.24/src/VBox/Devices/Makefile.kmk
===================================================================
--- VirtualBox-5.0.24.orig/src/VBox/Devices/Makefile.kmk
+++ VirtualBox-5.0.24/src/VBox/Devices/Makefile.kmk
@@ -818,8 +818,7 @@ if !defined(VBOX_ONLY_EXTPACKS)
$(call MSG_TOOL,iasl,VBoxDD,$<,$@)
$(QUIET)$(RM) -f $@ $@.tmp $@.pre
$(QUIET)$(TOOL_$(VBOX_GCC_TOOL)_CC) -E -P -x c -o $@.pre $<
- $(QUIET)$(SED) -e "s/<NL>/\n/g" \
- --output $@.pre1 $@.pre
+ $(QUIET)$(SED) -e "s/<NL>/\n/g" $@.pre > $@.pre1
$(QUIET)$(VBOX_IASLCMD) -tc -vs -p $@ $@.pre1
$(QUIET)$(MV) -f $@ $@.tmp
$(QUIET)$(SED) -e "s/AmlCode/AmlCodeSsdtCpuHotPlug/g" \

View File

@ -1,27 +1,12 @@
diff -urN VirtualBox-5.0.0.old/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_printf.c VirtualBox-5.0.0/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_printf.c
--- VirtualBox-5.0.0.old/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_printf.c 2015-07-14 20:53:12.121479325 +0200
+++ VirtualBox-5.0.0/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_printf.c 2015-07-19 17:11:11.677617929 +0200
@@ -1568,10 +1568,10 @@
width = 0;
if (width != 0)
- f += snprintf(f, sizeof (format), "%d", ABS(width));
+ f += snprintf(f, sizeof (f), "%d", ABS(width));
if (prec > 0)
- f += snprintf(f, sizeof (format), ".%d", prec);
+ f += snprintf(f, sizeof (f), ".%d", prec);
(void) strcpy(f, pfd->pfd_fmt);
pfd->pfd_rec = rec;
diff -urN VirtualBox-5.0.0.old/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_subr.c VirtualBox-5.0.0/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_subr.c
--- VirtualBox-5.0.0.old/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_subr.c 2015-07-14 20:53:12.120479323 +0200
+++ VirtualBox-5.0.0/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_subr.c 2015-07-19 17:12:35.554945664 +0200
@@ -866,6 +866,7 @@
x = x + (x >> 32);
return (x & 0x7F);
Index: VirtualBox-5.1.4/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_subr.c
===================================================================
--- VirtualBox-5.1.4.orig/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_subr.c
+++ VirtualBox-5.1.4/src/VBox/ExtPacks/VBoxDTrace/onnv/lib/libdtrace/common/dt_subr.c
@@ -833,6 +833,7 @@ dt_gmatch(const char *s, const char *p)
#else
return (p == NULL || *p == '\0' || RTStrSimplePatternMatch(p, s)); /** @todo implement gmatch. */
#endif
+ return 0;
}
/*
char *

View File

@ -1,7 +1,8 @@
diff -urN VirtualBox-5.0.0.old/src/VBox/Additions/common/crOpenGL/Makefile.kmk VirtualBox-5.0.0/src/VBox/Additions/common/crOpenGL/Makefile.kmk
--- VirtualBox-5.0.0.old/src/VBox/Additions/common/crOpenGL/Makefile.kmk 2015-07-11 13:17:27.581698930 +0200
+++ VirtualBox-5.0.0/src/VBox/Additions/common/crOpenGL/Makefile.kmk 2015-07-11 13:19:09.146886862 +0200
@@ -67,18 +67,12 @@
Index: VirtualBox-5.1.2/src/VBox/Additions/common/crOpenGL/Makefile.kmk
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Additions/common/crOpenGL/Makefile.kmk
+++ VirtualBox-5.1.2/src/VBox/Additions/common/crOpenGL/Makefile.kmk
@@ -68,18 +68,12 @@ VBoxOGL_TEMPLATE = VBOXCROGLR3GUES
VBoxOGL_INCS = .
if1of ($(KBUILD_TARGET), linux solaris freebsd)
VBoxOGL_INCS += \
@ -25,7 +26,7 @@ diff -urN VirtualBox-5.0.0.old/src/VBox/Additions/common/crOpenGL/Makefile.kmk V
VBoxOGL_DEFS += VBOX_NO_NATIVEGL
endif
@@ -213,10 +207,10 @@
@@ -214,10 +208,10 @@ VBoxOGL_LIBS.win += \
if1of ($(KBUILD_TARGET), linux solaris freebsd)
VBoxOGL_LIBS += \
@ -40,10 +41,11 @@ diff -urN VirtualBox-5.0.0.old/src/VBox/Additions/common/crOpenGL/Makefile.kmk V
ifdef VBoxOGL_FAKEDRI
ifeq ($(KBUILD_TARGET), freebsd)
VBoxOGL_LIBS += \
diff -urN VirtualBox-5.0.0.old/src/VBox/Additions/common/VBoxGuestLib/Makefile.kmk VirtualBox-5.0.0/src/VBox/Additions/common/VBoxGuestLib/Makefile.kmk
--- VirtualBox-5.0.0.old/src/VBox/Additions/common/VBoxGuestLib/Makefile.kmk 2015-07-11 13:17:27.580698928 +0200
+++ VirtualBox-5.0.0/src/VBox/Additions/common/VBoxGuestLib/Makefile.kmk 2015-07-11 13:19:09.146886862 +0200
@@ -40,8 +40,6 @@
Index: VirtualBox-5.1.2/src/VBox/Additions/common/VBoxGuestLib/Makefile.kmk
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Additions/common/VBoxGuestLib/Makefile.kmk
+++ VirtualBox-5.1.2/src/VBox/Additions/common/VBoxGuestLib/Makefile.kmk
@@ -40,8 +40,6 @@ LIBRARIES += \
VBoxGuestR3LibShared
ifndef VBOX_ONLY_VALIDATIONKIT
if1of ($(KBUILD_TARGET), freebsd linux netbsd openbsd)

View File

@ -1,3 +1,203 @@
-------------------------------------------------------------------
Sun Aug 28 01:59:37 UTC 2016 - Larry.Finger@lwfinger.net
- Add "ExclusiveArch: %ix86 x86_64" line back into the spec file.
Handle a false positive indication from kmemleak. This patch is added to "modify_for_4_8_bo_move.patch".
-------------------------------------------------------------------
Thu Aug 18 20:24:23 UTC 2016 - Larry.Finger@lwfinger.net
- The API for ttm_bo_move_memcpy() is changed in kernel 4.8.
Add patch file "modify_for_4_8_bo_move.patch" to handle this case.
-------------------------------------------------------------------
Thu Aug 18 18:29:35 UTC 2016 - Larry.Finger@lwfinger.net
- Version bump to 5.1.4 (released 2016-08-16 by Oracle)
This is a maintenance release. The following items were fixed and/or added:
GUI: show actual VM uptime in the session information window
Audio: re-enabled speakers for Mac OS X guests (5.1.0 regression; bug #15611)
Audio: fixed crashes under certain conditions
USB: fixed a hang under certain conditions
USB: fixed a hanging guest under certain conditions (bug #15747)
PIIX4: implemented dummy SMBus controller to prevent annoying Linux kernel warnings about uninitialized SMBus base address (bug #9517)
NVMe: several fixes to improve stability, fixed a crash while saving a VM state
VMDK: Fixed an issue creating fixed size images with certain sizes and the Split2G option enabled (bug #15748)
VHDX: fixed cloning images with VBoxManage clonehd (bug #14288)
Storage: Fixed broken bandwidth limitation when the limit is very low (bug #14982)
EFI: fixed sending debug messages in the EFI firmware if a serial port is enabled (bug #12161)
OVF: when importing appliances, make sure that the version of the embedded VirtualBox-specific settings is processed, to get the default settings handling right
VBoxManage: Don't try to set the medium type if there is no change (bug #13850)
Linux installer: fixed some scripting issues (bugs #15701 and #15702)
Linux installer: fixed a path issue on certain Linux distributions (bug #15717)
Windows hosts: fixed corrupted mouse pointers with some Linux and Solaris guests (bug #15665)
Linux Additions: made the video driver work on 32-bit guests with large video memory sizes (bug #15621)
Linux Additions: made the video driver work on kernel 4.7 and later (bug #15769)
Linux Additions: converted a failure message to an informational one when drivers could not be stopped during upgrade (bug #15692)
Linux Additions: made the video driver work around an X server bug which cause screen refresh to stop (bug #15511)
Windows Additions: auto-resizing fixes for Windows 10 guests (bug #15257)
Windows Additions: fixed VBoxTray problems with Windows 2000 (bug #15661)
- Other local changes:
"changeset_60565.diff" is removed - fixed in upstream.
"vbox-kernel47-cpu_has_pge.diff" -s removed - also fixed in upstream.
-------------------------------------------------------------------
Thu Aug 11 19:38:37 UTC 2016 - hpj@urpla.net
- adjust file attributes on SUID helpers to avoid chkstat issues
-------------------------------------------------------------------
Thu Aug 11 11:48:53 UTC 2016 - hpj@urpla.net
- remove obsolete libgsoap-devel (again)
- remove /usr/lib/udev/rules.d/60-vboxdrv.rules
- it is overruled from vboxdrv init script anyway
- vboxdrv generates a /etc/udev/rules.d/60-vboxdrv.rules file
on _every_ start, note that fact in /etc/default/virtualbox
and describe a strategy to control this behaviour
- relocate VBoxCreateUSBNode.sh to /usr/lib/virtualbox
this is, where vboxdrv, resp. the generated 60-vboxdrv.rules
file is expecting it
-------------------------------------------------------------------
Mon Aug 8 17:13:27 UTC 2016 - Larry.Finger@lwfinger.net
- Remove request for patch that is no longer used.
-------------------------------------------------------------------
Mon Aug 8 17:04:19 UTC 2016 - Larry.Finger@lwfinger.net
- Patch11 is file "vbox-kernel47-cpu_has_pge.diff".
-------------------------------------------------------------------
Mon Aug 8 11:57:18 UTC 2016 - bruno@ioda-net.ch
- Add upstream patch fix cpu_has_pge removed macro in kernel 4.7
Patch11
- Add ifarch ix86 to limit concurrency on 32bits (-j2)
Remove ExcludeArch instructions
-------------------------------------------------------------------
Fri Jul 22 00:49:00 UTC 2016 - luizluca@tre-sc.jus.br
- Version bump to 5.1.2 (released 2016-07-21 by Oracle)
New main capabilities in Oracle VM VirtualBox 5.1 are:
Improved Performance: Significantly improved performance for multi-CPU virtual machines and networking.
Bug Reporting Tool: New utility able to collect all the information and logs related to the host and guest operating system, for debug or analysis purposes.
Improved Logging Window: New logging functionalities to highlight and filter information related to guest Virtual Machines.
Improved multimedia availability: Improved support for different USB devices and multi-channel audio availability.
Flash storage emulation: New NVMHCI storage controller emulation available, able to emulate NVME devices - Flash storage - on guest Virtual Machine.
Improved Linux integration: Automatic modules deployment in case of a Linux Kernel upgrade and improved systemd integration for the latest releases of popular Linux distributions.
- Drop drm-vboxvideo-Add-delayed-update-to-support-fbdev.patch, fixed upstream.
- Drop drm-vboxvideo-Initialize-data-needed-to-map-fbdev-memory.patch, fixed upstream.
- Drop vbox-4.7.patch, fixed upstream.
- vbox-permissions_warning.diff and vbox-usb-warning.diff updated to Qt5
- User Manual updated.
-------------------------------------------------------------------
Thu Jul 21 19:18:39 UTC 2016 - adam@mizerski.pl
- virtualbox-60-vboxdrv.rules: added missing udev rules for
vboxdrvu and vboxnetctl (http://www.mgreene.org/?p=211)
-------------------------------------------------------------------
Tue Jul 20 19:03:36 UTC 2016 - Larry.Finger@lwfinger.net
- Disable i586 builds as they fail with the OBS compiler.
Increased VM to 20000 M.
- Version bump to 5.0.26 (released 2016-07-18 by Oracle)
This is a maintenance release. The following items were fixed and/or added:
VMM: fixed a bug in the task switching code (ticket #15571)
GUI: allow to overwrite an existing file when saving a log file (bug #8034)
GUI: fixed screenshot if the VM is started in separate mode
Audio: improved recording from USB headsets and other sources which might need conversion of captured data
Audio: fixed regression of not having any audio available on Solaris hosts
VGA: fixed an occasional hang when running Windows guests with 3D enabled
Storage: fixed a possible endless reconnect loop for the iSCSI backend if connecting to the target succeeds but further I/O requests cause a disconnect
Storage: fixed a bug when resizing certain VDI images which resulted in using the whole disk on the host (bug #15582)
EFI: fixed access to devices attached to SATA port 2 and higher (bug #15607)
API: fixed video recording with VBoxHeadless (bug #15443)
API: don't crash if there is no graphics controller configured (bug #15628)
VBoxSVC: fixed several memory leaks when handling .dmg images
Solaris hosts: fixed a crash on hosts with certain CPU configurations
Windows hosts: properly fall back to NDIS5 on pre-Vista hosts on silent installations
-------------------------------------------------------------------
Mon Jul 18 15:24:19 UTC 2016 - Larry.Finger@lwfinger.net
- Version bump to 5.0.24 (released 2016-06-28 by Oracle)
This is a maintenance release. The following items were fixed and/or added:
VMM: reverted to the old I/O-APIC code for now to fix certain regressions with 5.0.22 (bug #15529). This means that the networking performance with certain guests will drop to the 5.0.20 level (bug #15295). One workaround is to disable GRO for Linux guests.
Main: when taking a screenshot, don't save garbage for blanked screens
NAT: correctly parse resolv.conf file with multiple separators (5.0.22 regression)
Storage: fixed a possible corruption of stream optimized VMDK images from VMware when opened in read/write mode for the first time
Audio: imlemented dynamic re-attaching of input/output devices on Mac OS X hosts
ACPI: notify the guest when the battery / AC state changes instead of relying on guest polling
Linux hosts: fixed VERR_VMM_SET_JMP_ABORTED_RESUME Guru Meditations on hosts with Linux 4.6 or later (bug #15439)
-------------------------------------------------------------------
Mon Jun 20 16:18:19 UTC 2016 - Larry.Finger@lwfinger.net
- Version bump to 5.0.22 (released 2016-06-16 by Oracle)
This is a maintenance release. The following items were fixed and/or added:
VMM: fixes for certain Intel Atom hosts (bug #14915)
VMM: properly restore the complete FPU state for 32-bit guests on 64-bit hosts on Intel Sandy Bridge and Ivy Bridge CPUs
VMM: new I/O-APIC implementation fixing several bugs and improving the performance under certain conditions (bug #15295 and others)
VMM: fixed a potential Linux guest panic on AMD hosts
VMM: fixed a potential hang with 32-bit EFI guests on Intel CPUs (VT-x without unrestricted guest execution)
GUI: don't allow to start subsequent separate VM instances
GUI: raised upper limit for video capture screen resolution (bug #15432)
GUI: warn if the VM has less than 128MB VRAM configured and 3D enabled
Main: when monitoring DNS configuration changes on Windows hosts avoid false positives from competing DHCP renewals. This should fix NAT link flaps when host has multiple DHCP configured interfaces, in particular when the host uses OpnVPN.
Main: properly display an error message if the VRDE server cannot be enabled at runtime, for example because another service is using the same port
NAT: Initialize guest address guess for wildcard port-forwarding rules with default guest address (bug #15412)
VGA: fix for a problem which made certain legacy guests crash under certain conditions (bug #14811)
ACPI: properly notify the guest if the ACPI battery state changed
OVF: fixed import problems for some appliances using an AHCI controller created by 3rd party applications
SDK: reduced memory usage in the webservice Java bindings
Linux hosts: EL 6.8 fix (bug #15411)
Linux hosts: Linux 4.7 fix (bug #15459)
Linux Additions: Linux 4.7 fixes (bug #15444)
Linux Additions: fix for certain 32-bit guests (5.0.18 regression; bug #15320)
Linux Additions: fixed mouse pointer offset (5.0.18 regression; bug #15324)
Linux Additions: made old X.Org releases work again with kernels 3.11 and later (5.0.18 regression; bug #15319)
Linux Additions: fixed X.Org crash after hard guest reset (5.0.18 regression; bug #15354)
Linux Additions: don't stop the X11 setup if loading the shared folders module fails (5.0.18 regression)
Linux Additions: don't complain if the Drag and Drop service is not available on the host
Solaris Additions: added support for X.org 1.18
Local openSUSE specific changes:
File "changeset_60565.diff" is no longer needced and has been removed.
Version bump to 5.0.20 (released 2016-04-28 by Oracle)
This is a maintenance release. The following items were fixed and/or added:
Storage: fixed a regression causing write requests from the BIOS to cause a Guru Meditation with the LsiLogic SCSI controller (5.0.18 regression; bug #15317)
Storage: several emulation fixes in the BusLogic SCSI controller emulation
NAT Network: support TCP in DNS proxy (same problem as in bug #14736 for NAT)
NAT: rework handling of port-forwarding rules (bug #13570)
NAT: rewrite host resolver to handle more query types and make it asynchronous so that a stalled lookup doesn't block all NAT traffic
Snapshots: don't crash when restoring a snapshot which has more network adapters than the current state (ie when the snapshot uses ICH9 and the current state uses PIIX3)
Guest Control: various bugfixes for the copyfrom and copyto commands / API (bug #14336)
VBoxManage: list processor features on list hostinfo (bug #15334)
Linux hosts: fix for Linux 4.5 if CONFIG_NET_CLS_ACT is enabled (bug #15327)
Windows Additions: fixed performance issues with PowerPoint 2010 and the WDDM graphics drivers if Aero is disabled
-------------------------------------------------------------------
Tue Jun 7 19:03:36 UTC 2016 - Larry.Finger@lwfinger.net
@ -9,9 +209,12 @@ Wed May 18 14:09:11 UTC 2016 - hpj@urpla.net
- remove libgsoap-devel from build deps, it conflicts with gsoap-devel
-------------------------------------------------------------------
Sun May 8 18:19:23 UTC 2016 - Larry.Finger@lwfinger.net
Fri May 6 20:04:53 UTC 2016 - Larry.Finger@lwfinger.net
- Fix start failure of vboxadd service routine (boo #977328). With this change, automounting of shared folders works again.
- Fix start failure of vboxadd service routine
This script fails because /var/lib/VBoxGuestAdditions/config does not exist; however, there is no need
for this file. That service routine is modified.
(boo #977328).
-------------------------------------------------------------------
Tue Apr 26 11:23:41 UTC 2016 - eich@suse.com
@ -157,9 +360,7 @@ This is a maintenance release. The following items were fixed and/or added:
BIOS: properly report if two floppy drives are attached
USB: fixed a problem with filters which would not capture the device under certain circumstances (5.0.10 regression; bug #15042)
ExtPack: black-list Extension Packs older than 4.3.30 due to incompatible changes not being properly handled in the past
Windows hosts: fixed a regression which caused robocopy to fail (bug #14958)
Linux hosts: properly create the /sbin/rcvboxdrv symbolic link (5.0.12 regression; bug #14989)
Mac OS X hosts: several fixes for USB on El Capitan (bug #14677)
Linux Additions: fixes for Linux 4.5 (bug #15032)
@ -194,15 +395,13 @@ This is a maintenance release. The following items were fixed and/or added:
rdesktop-vrdp: source code tarball fixes
Linux hosts: .desktop file compatibility issue (bug #14808)
Linux hosts / guests: fixes for RHEL 7.2 (bug #14866)
The command for recompiling the host kernel modules was changed again, to /sbin/rcvboxdrv setup (bug #14723)
Linux hosts: The command for recompiling the host kernel modules was changed again, to /sbin/rcvboxdrv setup (bug #14723)
Linux hosts: some fixes for PCI passthrough (still highly experimental)
Linux/Mac OS X hosts: fixed a VM hang during startup under certain circumstances (bug #14933)
Linux Additions: prevent the compiler from doing dead-code elemination on vital code in guest / host communication (bug #14497)
Linux Additions: when mounting a shared folder, explicitly pass the share name so that /proc/mounts contains this name instead of 'none'
Linux Additions: workaround for a systemd problem in conjunction with SELinux which prevented to properly enable the 'vboxadd' service during while upgrading the Additions
-------------------------------------------------------------------
Sun Dec 20 06:46:49 UTC 2015 - mailaender@opensuse.org
@ -264,16 +463,21 @@ This is a maintenance release. The following items were fixed and/or added:
Windows host installer: fixed not starting the actual installation when showing the version information or help dialogs
X11 Additions: added basic support for X.Org Server 1.18 (3D requires additional fixes)
- Refresh vbox-no-build-dates.diff
-------------------------------------------------------------------
Fri Nov 6 19:43:55 UTC 2015 - Larry.Finger@lwfinger.net
- Fixed typo in QMessageBox text in new popup window.
-------------------------------------------------------------------
Sun Nov 8 05:10:36 UTC 2015 - Larry.Finger@lwfinger.net
Fri Nov 6 06:57:16 UTC 2015 - Larry.Finger@lwfinger.net
- Add a popup window to the VB startup wrapper to make clear why USB passthru is not automatically
enabled, and explain what steps the user should take if this feature is wanted despite the security
hole.
- Add logic to virtualbox-wrapper.sh to test if /etc/udev/rules.d/60-vboxdrv.rules exists. If not, a screen stating
that passthru of USB devices is a security hole, and it refers the user to bnc#664520 for an explanation.
It also explains the process for enabling USB passthru if the user really wants it. When the user closes
the popup window, a dummy version of /etc/udev/rules.d/60-vboxdrv.rules is created, which prevents this
window from being displayed every time VirtualBox is started.
Patch file vbox-usb-warning.diff fixes the problem shown in boo#953018.
- Fixes boo#953018.
-------------------------------------------------------------------
Tue Oct 20 19:01:09 UTC 2015 - Larry.Finger@lwfinger.net
@ -294,11 +498,6 @@ This is a maintenance release. The following items were fixed and/or added:
Windows Additions: fixed problems with 3D acceleration on Windows hosts with Intel HD graphics (bug #14670)
Linux Additions: fix service starting on Debian systems with systemd installed but not in use (bug #14683)
-------------------------------------------------------------------
Thu Oct 15 15:55:20 UTC 2015 - Larry.Finger@lwfinger.net
- Increase memory constraint to 5000M
-------------------------------------------------------------------
Mon Oct 5 07:35:22 UTC 2015 - idonmez@suse.com

View File

@ -19,7 +19,7 @@
%define _vbox_instdir %{_libexecdir}/virtualbox
%define _udevrulesdir %{_libexecdir}/udev/rules.d
Name: virtualbox
Version: 5.0.18
Version: 5.1.4
Release: 0
Summary: VirtualBox is an Emulator
License: GPL-2.0+
@ -32,7 +32,6 @@ Url: http://www.virtualbox.org/
#%(bash %{_sourcedir}/virtualbox-patch-source.sh VirtualBox-%{version}.tar.bz2)
Source0: VirtualBox-%{version}-patched.tar.bz2
Source1: UserManual.pdf
Source2: %{name}-60-vboxdrv.rules
Source3: %{name}-60-vboxguest.rules
Source4: %{name}-default.virtualbox
Source5: %{name}-host-kmp-files
@ -85,13 +84,8 @@ Patch108: virtualbox-snpritnf-buffer-overflow.patch
Patch109: vbox-usb-warning.diff
# Prevent Guest Additions from creating wrong SONAME
Patch111: vbox_prevent_wrong_SONAME.patch
# Apply Changeset 60565 - Fix bug in DevLsiLogicSCSI.cpp
Patch112: changeset_60565.diff
# Patch to make xf86-video-fbdev work on vboxvideodrm
Patch114: drm-vboxvideo-Initialize-data-needed-to-map-fbdev-memory.patch
Patch113: drm-vboxvideo-Add-delayed-update-to-support-fbdev.patch
# Patch to allow 5.0.18 to build on kernel 4.7
Patch115: vbox-4.7.patch
# Fix change in kernel API for ttm_bo_move_memcpy()
Patch112: modify_for_4_8_bo_move.patch
#
BuildRequires: LibVNCServer-devel
BuildRequires: SDL-devel
@ -109,13 +103,15 @@ BuildRequires: gcc-c++
BuildRequires: glibc-devel-static
BuildRequires: gsoap-devel
BuildRequires: java-devel >= 1.6.0
BuildRequires: kbuild >= 0.1.9998svn2689
BuildRequires: kbuild >= 0.1.9998svn2808
BuildRequires: kernel-syms
BuildRequires: libcap-devel
BuildRequires: libcurl-devel
BuildRequires: libidl-devel
BuildRequires: libopenssl-devel
BuildRequires: libqt4-devel
BuildRequires: libqt5-linguist
BuildRequires: libqt5-qtbase-devel
BuildRequires: libqt5-qtx11extras-devel
BuildRequires: libvpx-devel
BuildRequires: libxslt-devel
BuildRequires: module-init-tools
@ -132,6 +128,7 @@ BuildRequires: xorg-x11-server-sdk
BuildRequires: yasm
BuildRequires: zlib-devel-static
BuildRequires: pkgconfig(fontsproto)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(randrproto)
BuildRequires: pkgconfig(renderproto)
BuildRequires: pkgconfig(resourceproto)
@ -140,13 +137,17 @@ BuildRequires: pkgconfig(udev)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(xau)
BuildRequires: pkgconfig(xcomposite)
BuildRequires: pkgconfig(xcursor)
BuildRequires: pkgconfig(xdmcp)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xextproto)
BuildRequires: pkgconfig(xf86driproto)
BuildRequires: pkgconfig(xfixes)
BuildRequires: pkgconfig(xinerama)
BuildRequires: pkgconfig(xineramaproto)
BuildRequires: pkgconfig(xmu)
BuildRequires: pkgconfig(xproto)
BuildRequires: pkgconfig(xrandr)
Requires: %{name}-host-kmp = %{version}
Requires(post): sysvinit(syslog)
Requires(pre): permissions
@ -157,12 +158,7 @@ Provides: %{name}-ose = %{version}
Obsoletes: %{name}-ose < %{version}
BuildRoot: %{_tmppath}/%{name}-%{version}-build
%(sed -e '/^Provides: multiversion(kernel)/d' %{_libexecdir}/rpm/kernel-module-subpackage > %{_builddir}/virtualbox-kmp-template)
# Temporarily disable i586 until build problem is solved
#ExclusiveArch: %ix86 x86_64
#%if 0%{?suse_version} == 1315
#ExcludeArch: %ix86
#%endif
ExclusiveArch: x86_64
ExclusiveArch: %ix86 x86_64
%ifarch amd64 x86_64 ia32e em64t
BuildRequires: gcc-32bit
BuildRequires: gcc-c++-32bit
@ -303,7 +299,7 @@ This package contains icons for guest desktop files that were created on the des
%prep
%setup -q -n VirtualBox-%{version}
%patch1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
@ -323,9 +319,7 @@ This package contains icons for guest desktop files that were created on the des
%patch109 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1
%patch114 -p1
%patch115 -p1
#copy user manual
cp %{SOURCE1} UserManual.pdf
#copy kbuild config
@ -355,7 +349,6 @@ echo "SED = $RPM_BUILD_DIR/VirtualBox-%{version}/kmk_sed" >> LocalConfig.kmk
rm -rf src/libs/{libpng-*,libxml2-*,libxslt-*,zlib-*,boost-*}
# --disable-kmods don't build Linux kernel modules - but use SUSE specific way see few lines under
# --nofatal try to avoid build fail caused by missing makeself package
# NOT an autoconf configure macro
./configure \
--ose \
@ -365,8 +358,9 @@ rm -rf src/libs/{libpng-*,libxml2-*,libxslt-*,zlib-*,boost-*}
--with-linux="/usr" \
--disable-java \
--disable-docs \
--nofatal \
--enable-webservice
--enable-webservice \
--with-mkisofs=/bin/true \
--with-makeself=/bin/true
# configure actually warns we should source env.sh (which seems like it could influence the build...)
source ./env.sh
@ -375,7 +369,11 @@ source ./env.sh
# VBOX_PATH_PACKAGE_DOCS set propper path for link to pdf in .desktop file
# VBOX_WITH_REGISTRATION_REQUEST= VBOX_WITH_UPDATE_REQUEST= just disable some functionality in gui
echo "build basic parts"
%{_bindir}/kmk %{?_smp_mflags} \
%ifarch %ix86
%{_bindir}/kmk -j2 \
%else
%{_bindir}/kmk %{?_smp_mflags} \
%endif
VBOX_GCC_WERR= \
KBUILD_VERBOSE=2 \
VBOX_USE_SYSTEM_XORG_HEADERS=1 \
@ -387,8 +385,8 @@ echo "build basic parts"
#
# build kernel modules for guest and host (check novel-kmp package as example)
# host modules : vboxdrv,vboxnetflt,vboxnetadp
# guest modules : vboxguest,vboxsf,vboxvideo, vboxpci
# host modules : vboxdrv,vboxnetflt,vboxnetadp,vboxpci
# guest modules : vboxguest,vboxsf,vboxvideo
echo "build kernel modules"
for vbox_module in out/linux.*/release/bin/src/vbox{drv,netflt,netadp,pci} \
out/linux.*/release/bin/additions/src/vbox{guest,sf,video}; do
@ -418,13 +416,13 @@ for vbox_module in out/linux.*/release/bin/src/vbox{drv,netflt,netadp,pci} \
cp $PWD/modules_build_dir/$flavor/vboxguest/Module.symvers \
$PWD/modules_build_dir/$flavor/$module_name
fi
# copy vboxguest (for guest) module symbols which are used by vboxvideo km:
if [ "$module_name" = "vboxvideo" ]; then
cp $PWD/modules_build_dir/$flavor/vboxguest/Module.symvers \
$PWD/modules_build_dir/$flavor/$module_name
fi
# build the module for the specific flavor
make %{?_smp_mflags} -C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules \
%ifarch %ix86
make -j2 \
%else
make %{?_smp_mflags} \
%endif
-C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules \
M=$PWD/modules_build_dir/$flavor/$module_name
done
done
@ -473,15 +471,13 @@ install -m 755 out/linux.*/release/bin/additions/VBoxService %{buildroot}%{_sbin
install -m 755 out/linux.*/release/bin/additions/mount.vboxsf %{buildroot}/sbin/mount.vboxsf
install -m 744 src/VBox/Additions/linux/installer/vboxadd.sh %{buildroot}%{_sysconfdir}/init.d/vboxadd
install -m 744 src/VBox/Additions/linux/installer/vboxadd-service.sh %{buildroot}%{_sysconfdir}/init.d/vboxadd-service
install -D -m 744 src/VBox/Additions/linux/installer/vboxadd.sh %{buildroot}/opt/VBoxGuestAdditions-%{version}/init/vboxadd
install -D -m 744 src/VBox/Additions/linux/installer/vboxadd-service.sh %{buildroot}/opt/VBoxGuestAdditions-%{version}/init/vboxadd-service
ln -s %{_sysconfdir}/init.d/vboxadd %{buildroot}%{_sbindir}/rcvboxadd
ln -s %{_sysconfdir}/init.d/vboxadd-service %{buildroot}%{_sbindir}/rcvboxadd-service
# udev rule for guest (virtualbox-guest-tools)
install -m 644 %{SOURCE3} %{buildroot}%{_udevrulesdir}/60-vboxguest.rules
# /media is used for auto-mounting of shared folders
%if 0%{?suse_version} > 1310
install -d 755 %{buildroot}/media
install -d -m 755 %{buildroot}/media
%endif
#
##############################################################
@ -549,8 +545,6 @@ install -m 644 out/linux.*/release/bin/virtualbox.desktop %{buildroot}%{_datadir
# create a menu entry
install -m 644 out/linux.*/release/bin/VBox.png %{buildroot}%{_datadir}/pixmaps/virtualbox.png
# install udev rule for host (virtualbox)
install -m 644 %{SOURCE2} %{buildroot}%{_udevrulesdir}/60-vboxdrv.rules
# install config with session shutdown defs
install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/default/virtualbox
#install wrapper script
@ -559,8 +553,8 @@ install -m 644 %{SOURCE9} %{buildroot}%{_bindir}/VirtualBox
# modify and install the vboxdrv init script
# TODO: some of this stuff breaks the fillup macros below?
sed -i "s|%{NOLSB}%|yes|g;s|%{DEBIAN}%||g;s|%{PACKAGE}%|virtualbox|g" \
src/VBox/Installer/linux/vboxdrv.sh.in
install -m 744 src/VBox/Installer/linux/vboxdrv.sh.in %{buildroot}%{_sysconfdir}/init.d/vboxdrv
src/VBox/Installer/linux/vboxdrv.sh
install -m 744 src/VBox/Installer/linux/vboxdrv.sh %{buildroot}%{_sysconfdir}/init.d/vboxdrv
ln -s %{_sysconfdir}/init.d/vboxdrv %{buildroot}%{_sbindir}/rcvboxdrv
# Init script to start virtual boxes during boot
install -m 755 %{SOURCE12} %{buildroot}%{_sysconfdir}/init.d/vboxes
@ -573,7 +567,7 @@ install -m 640 %{SOURCE13} %{buildroot}%{_var}/adm/fillup-templates/sysconfig.vb
install -d -m 755 %{buildroot}%{_sysconfdir}/vbox
echo -e "#settings for vboxwebsrn\nVBOXWEB_USER=root" > %{buildroot}%{_sysconfdir}/vbox/vbox.cfg
# install udev helper script for creating usb devices
install -m 0755 -D src/VBox/Installer/linux/VBoxCreateUSBNode.sh %{buildroot}%{_udevrulesdir}/../VBoxCreateUSBNode.sh
install -m 0755 -D src/VBox/Installer/linux/VBoxCreateUSBNode.sh %{buildroot}%{_vbox_instdir}/VBoxCreateUSBNode.sh
######################################################
echo "entrering python-virtualbox install section"
######################################################
@ -774,7 +768,6 @@ exit 0
%{_vbox_instdir}/components/*.xpt
%dir %{_datadir}/virtualbox
%config %{_sysconfdir}/default/virtualbox
%{_udevrulesdir}/60-vboxdrv.rules
%config %{_sysconfdir}/init.d/vboxdrv
%dir %{_sysconfdir}/vbox
%config %{_sysconfdir}/vbox/vbox.cfg
@ -782,16 +775,17 @@ exit 0
%{_var}/adm/fillup-templates/sysconfig.vbox
%{_sbindir}/rcvboxes
%{_sbindir}/rcvboxdrv
%{_udevrulesdir}/../VBoxCreateUSBNode.sh
%verify(not mode) %attr(4711,root,vboxusers) %{_vbox_instdir}/VBoxNetDHCP
%verify(not mode) %attr(4711,root,vboxusers) %{_vbox_instdir}/VBoxNetAdpCtl
%verify(not mode) %attr(4711,root,vboxusers) %{_vbox_instdir}/VBoxHeadless
%verify(not mode) %attr(4711,root,vboxusers) %{_vbox_instdir}/VBoxSDL
%{_vbox_instdir}/VBoxCreateUSBNode.sh
#%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxNetNAT
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxNetDHCP
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxNetAdpCtl
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxHeadless
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxSDL
%files qt
%defattr(-, root, root)
%attr(0755,root,vboxusers) %{_vbox_instdir}/VBoxPermissionMessage
%verify(not mode) %attr(4711,root,vboxusers) %{_vbox_instdir}/VirtualBox
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VirtualBox
#wrapper script is in bindir
%attr(0755,root,root) %{_bindir}/VirtualBox
#ldd shows libQt* dependency
@ -823,10 +817,6 @@ exit 0
%config %{_sysconfdir}/init.d/vboxadd-service
%{_sbindir}/rcvboxadd
%{_sbindir}/rcvboxadd-service
%dir /opt/VBoxGuestAdditions-%{version}
%dir /opt/VBoxGuestAdditions-%{version}/init
/opt/VBoxGuestAdditions-%{version}/init/vboxadd
/opt/VBoxGuestAdditions-%{version}/init/vboxadd-service
%if 0%{?suse_version} > 1310
%dir /media
%endif
Index: VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
+++ VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
@@ -327,15 +327,15 @@ void UINameAndSystemEditor::sltFamilyCha
if (iIndexWin7 != -1)
m_pTypeCombo->setCurrentIndex(iIndexWin7);
m_pComboType->setCurrentIndex(iIndexWin7);
}
/* Or select Ubuntu item for Linux family as default: */
@ -12,12 +14,12 @@
+ QString strDefaultID = "openSUSE";
if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
strDefaultID += "_64";
- int iIndexUbuntu = m_pTypeCombo->findData(strDefaultID, TypeID);
- const int iIndexUbuntu = m_pComboType->findData(strDefaultID, TypeID);
- if (iIndexUbuntu != -1)
- m_pTypeCombo->setCurrentIndex(iIndexUbuntu);
+ int iIndexopenSUSE = m_pTypeCombo->findData(strDefaultID, TypeID);
+ if (iIndexopenSUSE != -1)
+ m_pTypeCombo->setCurrentIndex(iIndexopenSUSE);
- m_pComboType->setCurrentIndex(iIndexUbuntu);
+ const int iIndexOpenSUSE = m_pComboType->findData(strDefaultID, TypeID);
+ if (iIndexOpenSUSE != -1)
+ m_pComboType->setCurrentIndex(iIndexOpenSUSE);
}
/* Else simply select the first one present: */
else m_pTypeCombo->setCurrentIndex(0);
else

View File

@ -1,12 +1,13 @@
@@ -327,15 +327,15 @@ void UINameAndSystemEditor::sltFamilyCha
m_pComboType->setCurrentIndex(iIndexWin7);
}
- /* Or select Ubuntu item for Linux family as default: */
+ /* Or select openSUSE item for Linux family as default: */